@@ -31,6 +31,7 @@
 #include <telepathy-yell/telepathy-yell.h>
 
 #include <libempathy/empathy-tp-contact-factory.h>
+#include <libempathy/empathy-camera-monitor.h>
 #include <libempathy/empathy-contact-manager.h>
 #include <libempathy/empathy-utils.h>
 #include <libempathy/empathy-request-util.h>
@@ -59,6 +60,8 @@ typedef struct {
 
 struct _EmpathyNewCallDialogPriv {
   GtkWidget *check_video;
+
+  EmpathyCameraMonitor *monitor;
 };
 
 #define GET_PRIV(o) \
@@ -103,20 +106,26 @@ out:
 }
 
 static void
-conn_prepared_cb (GObject *conn,
-    GAsyncResult *result,
-    gpointer user_data)
+empathy_new_call_dialog_account_filter (EmpathyContactSelectorDialog *dialog,
+    EmpathyAccountChooserFilterResultCallback callback,
+    gpointer callback_data,
+    TpAccount *account)
 {
-  FilterCallbackData *data = user_data;
-  GError *myerr = NULL;
+  TpConnection *connection;
+  gboolean supported = FALSE;
+  guint i;
   TpCapabilities *caps;
   GPtrArray *classes;
-  guint i;
 
-  if (!tp_proxy_prepare_finish (conn, result, &myerr))
+  /* check if CM supports calls */
+  connection = tp_account_get_connection (account);
+  if (connection == NULL)
+      goto out;
+
+  caps = tp_connection_get_capabilities (connection);
+  if (caps == NULL)
       goto out;
 
-  caps = tp_connection_get_capabilities (TP_CONNECTION (conn));
   classes = tp_capabilities_get_channel_classes (caps);
 
   for (i = 0; i < classes->len; i++)
@@ -138,45 +147,22 @@ conn_prepared_cb (GObject *conn,
           TP_HANDLE_TYPE_CONTACT)
         continue;
 
-      data->callback (TRUE, data->user_data);
-      g_slice_free (FilterCallbackData, data);
-      return;
+      supported = TRUE;
+      break;
     }
 
 out:
-  data->callback (FALSE, data->user_data);
-  g_slice_free (FilterCallbackData, data);
+  callback (supported, callback_data);
 }
 
 static void
-empathy_new_call_dialog_account_filter (EmpathyContactSelectorDialog *dialog,
-    EmpathyAccountChooserFilterResultCallback callback,
-    gpointer callback_data,
-    TpAccount *account)
+empathy_new_call_dialog_dispose (GObject *object)
 {
-  TpConnection *connection;
-  FilterCallbackData *cb_data;
-  GQuark features[] = { TP_CONNECTION_FEATURE_CAPABILITIES, 0 };
+  EmpathyNewCallDialogPriv *priv = GET_PRIV (object);
 
-  if (tp_account_get_connection_status (account, NULL) !=
-      TP_CONNECTION_STATUS_CONNECTED)
-    {
-      callback (FALSE, callback_data);
-      return;
-    }
+  tp_clear_object (&priv->monitor);
 
-  /* check if CM supports calls */
-  connection = tp_account_get_connection (account);
-  if (connection == NULL)
-    {
-      callback (FALSE, callback_data);
-      return;
-    }
-
-  cb_data = g_slice_new0 (FilterCallbackData);
-  cb_data->callback = callback;
-  cb_data->user_data = callback_data;
-  tp_proxy_prepare_async (connection, features, conn_prepared_cb, cb_data);
+  G_OBJECT_CLASS (empathy_new_call_dialog_parent_class)->dispose (object);
 }
 
 static GObject *
@@ -212,8 +198,13 @@ empathy_new_call_dialog_init (EmpathyNewCallDialog *dialog)
   EmpathyNewCallDialogPriv *priv = GET_PRIV (dialog);
   GtkWidget *image;
 
+  priv->monitor = empathy_camera_monitor_dup_singleton ();
+
   /* add video toggle */
   priv->check_video = gtk_check_button_new_with_mnemonic (_("Send _Video"));
+  g_object_bind_property (priv->monitor, "available",
+      priv->check_video, "sensitive",
+      G_BINDING_SYNC_CREATE);
 
   gtk_box_pack_end (GTK_BOX (parent->vbox), priv->check_video,
       FALSE, TRUE, 0);
@@ -249,6 +240,7 @@ empathy_new_call_dialog_class_init (
   g_type_class_add_private (class, sizeof (EmpathyNewCallDialogPriv));
 
   object_class->constructor = empathy_new_call_dialog_constructor;
+  object_class->dispose = empathy_new_call_dialog_dispose;
 
   dialog_class->response = empathy_new_call_dialog_response;
 
